Computes enrichment (log-scale), standard error and p-value
Source:R/ctwas_summarize_parameters.R
compute_enrichment_test.RdComputes enrichment (log-scale), standard error and p-value
Arguments
- group_prior
a vector of prior inclusion probabilities for different groups.
- group_size
a vector of number of variables in different groups.
- enrichment_test
Method to test enrichment, "G": G-test, "fisher": Fisher's exact test, "z": p-value computed from z-score of enrichment.
- alternative
indicates the alternative hypothesis and must be one of "greater", "two.sided", or "less". Only used when
enrichment_testis "fisher" or "z".- include_test_result
If TRUE, return the original test result.