Converts fusion weights to predictDB format
Source:R/ctwas_weights.R
convert_fusion_to_predictdb.RdConverts fusion weights to predictDB format
Arguments
- weight_dir
the directory containing FUSION weights ('.wgt.RDat' files).
- fusion_method
a string, specifying the method to choose in FUSION models. "best.cv" option will use the best model (smallest p-value) under cross-validation.
- fusion_genome_version
a string, specifying the genome version of FUSION models
- make_extra_table
If TRUE, make an extra table in predictDB format
- cov_table
a data frame of covariances between variants, with columns: "GENE","RSID1","RSID2","VALUE". If NULL, do not create covariance files (.txg.gz).
- outputdir
output directory
- outname
name of the output weight file