Map SNPs to regions using all the variants in the LD reference.
Source:R/ctwas_snp_LD_map.R
create_snp_map.RdMap SNPs to regions using all the variants in the LD reference.
R/ctwas_snp_LD_map.R
create_snp_map.RdMap SNPs to regions using all the variants in the LD reference.