Get cross-boundary genes.
Usage
get_boundary_genes(
region_info,
weights,
gene_ids = NULL,
mapping_table = NULL,
show_mapping = TRUE,
ncore = 1
)Arguments
- region_info
a data frame of region definitions.
- weights
a list of preprocessed weights.
- gene_ids
a vector of selected gene IDs (z_gene$id). If specified, limits to these genes. Default: use all genes in weights.
- mapping_table
a data frame of mapping between molecular traits and genes, with required columns: "molecular_id", "gene_name".
- show_mapping
If TRUE, include the mapping between molecular traits and genes in the result.
- ncore
The number of cores used to parallelize over genes.