Merges region data for cross-boundary genes without using LD
Source:R/ctwas_merge_regions.R
merge_region_data_noLD.RdMerges region data for cross-boundary genes without using LD
Usage
merge_region_data_noLD(
boundary_genes,
region_data,
region_info,
snp_map,
z_snp,
z_gene,
expand = TRUE,
maxSNP = Inf,
ncore = 1,
verbose = FALSE,
logfile = NULL
)Arguments
- boundary_genes
a data frame of boundary gene info
- region_data
a list of original region_data
- region_info
a data frame of region definitions
- snp_map
a list of data frames with SNP-to-region map for the reference.
- z_snp
A data frame with columns: "id", "z", giving the z-scores for SNPs.
- z_gene
A data frame with columns: "id", "z", giving the z-scores for genes.
- expand
If TRUE, expand merged region_data with full SNPs
- maxSNP
Inf or integer. Maximum number of SNPs in a region. Default is Inf, no limit. This can be useful if there are many SNPs in a region and you don't have enough memory to run the program.
- ncore
The number of cores used to parallelize susie over regions
- verbose
If TRUE, print detail messages
- logfile
The log filename. If NULL, will print log info on screen.